California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 81 - SB 1161 (CHAPTER 698, 2004). ALPERT. CALIFORNIA READING AND LITERACY IMPROVEMENT AND PUBLIC LIBRARY CONSTRUCTION AND RENOVATION BOND ACT OF 2006. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1274465 | YES ON PROP. 81 - CALIFORNIANS FOR LITERACY AND COMMUNITY LIBRARIES, SUPPORTED BY THE CALIFORNIA LIBRARY ASSOCIATION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1288617 | CALIFORNIA LIBRARY ASSOCIATION COMMITTEE TO SUPPORT PROPOSITION 81 | SUPPORT